<?php
namespace Teknisa\FIS\Modules\Acessorias\Controllers;

use Teknisa\FIS\Modules\Acessorias\Services\Fis07800DacAlService;
use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response\Error;

class Fis07800DacAlController {

    protected $dacAlService;

    public function __construct(EntityManager $entityManager, Fis07800DacAlService $dacAlService) {
        $this->entityManager          = $entityManager;
        $this->dacAlService = $dacAlService;
    }

    /*
     * Função para realizar a exportação DAC-AL.
     */
    public function exportarDacAl(DTO\Request $request, DTO\Response $response) {
        try {
       
            $row = $request->getRow();
            
            $row["NMARQUIVO"] = str_replace(' ', '', $row["NMARQUIVO"]);

            // Chama a função de validação.
            $fileName = $this->dacAlService->exportarDacAl($row);

            // Retorna o nome do arquivo exportado.
            $response->addDataset(new DataSet('columnsToReturn', array("fileName" => $fileName)));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function findAgendamento(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            
            $rows = $this->dacAlService->findAgendamento();
            
            $dataSet = new DataSet('agendobrigacess_fis07800', $rows);
            $response->setDataSets(array($dataSet));
            
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    } 
    
    public function saveAgendamento(DTO\Request $request, DTO\Response $response) {
        try {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            
            $row = $request->getRow();
            
            $this->dacAlService->saveAgendamento($row);
            
            $this->entityManager->commit();

        } catch(\Exception $e) {
            $this->entityManager->rollback();
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function deleteAgendamento(DTO\Request $request, DTO\Response $response) {
        try {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            
            $row = $request->getRow();
            
            // Chama a função de validação.
            $this->dacAlService->deleteAgendamento($row);
            
            $this->entityManager->commit();

        } catch(\Exception $e) {
            $this->entityManager->rollback();
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function execAgendamentoDacAl(DTO\Request $request, DTO\Response $response) {
        try {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            
            $row = $request->getParameters();
            
            $this->dacAlService->execAgendamento($row);
            
            $this->entityManager->commit();

        } catch(\Exception $e) {
            $this->entityManager->rollback();
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
}


