<?php
namespace Teknisa\FIS\Modules\Acessorias\Factories;

use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;

class Fis07600ValidaPrFactory
{
    protected $connection;
    
    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
    }
    
    /**
     * Executa a procedure para a exportação de ValidaPR [ARQUIVO_VALIDAPR]
     */
    public function callValidaPrProcedure($params) {
        $procedure = new StoredProcedure($this->connection, 'ARQUIVO_VALIDAPR');
        
        $procedure->addParam(new Param('P_REGISTRO', Param::PARAM_INPUT, $params["CDREGISTRO"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDIMPOSTO', Param::PARAM_INPUT, $params["CDIMPOSTO"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDEMPRESA', Param::PARAM_INPUT, $params["CDEMPRESA"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDINSCESTA', Param::PARAM_INPUT, $params["CDINSCESTA"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTINICIAL', Param::PARAM_INPUT, $params["DTINICIAL"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTFINAL', Param::PARAM_INPUT, $params["DTFINAL"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTPOSICAO', Param::PARAM_INPUT, $params["DTPOSICAO"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDPAIS', Param::PARAM_INPUT, $params["CDPAIS"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_SGESTADO', Param::PARAM_INPUT, $params["SGESTADO"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_VERSAO', Param::PARAM_INPUT, $params["VERSAO"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_FINALIDADE', Param::PARAM_INPUT, $params["CDFINALIDADE"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRSEQARQMAG', Param::PARAM_INPUT, $params["NRSEQARQMAG"], Param::PARAM_TYPE_STR));
     
        $procedure->execute();
    }
    
    /**
     * Executa a procedure para a exportação de ADRC [ADRC_ST_PARANA]
     */
    public function callAdrcProcedure($params) {
        $procedure = new StoredProcedure($this->connection, 'ADRC_ST_PARANA');
        
        $procedure->addParam(new Param('P_CDEMPRESA', Param::PARAM_INPUT, $params["CDEMPRESA"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDINSCESTA', Param::PARAM_INPUT, $params["CDINSCESTA"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_VERSAO', Param::PARAM_INPUT, $params["VERSAO"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTINICIAL', Param::PARAM_INPUT, $params["DTINICIAL"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTFINAL', Param::PARAM_INPUT, $params["DTFINAL"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_FINALIDADE', Param::PARAM_INPUT, $params["FINALIDADE"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRREGESPECIAL', Param::PARAM_INPUT, $params["NRREGESPECIAL"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDCENTRDISTR', Param::PARAM_INPUT, $params["IDCENTRDISTR"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDEMPRESADISTR', Param::PARAM_INPUT, $params["CDEMPRESADISTR"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDINSCESTADISTR', Param::PARAM_INPUT, $params["CDINSCESTADISTR"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRSEQARQMAG', Param::PARAM_INPUT, $params["NRSEQARQMAG"], Param::PARAM_TYPE_STR));
     
        $procedure->execute();
    }
    
    /*
     * Função para excluir os dados gerados na procedure de ValidaPR.
     */
    public function deleteValidaPrData($params) {
        // Query a ser executada.
        $sql = "DELETE FROM ARQMAGNETICO WHERE NRSEQARQMAG = :NRSEQARQMAG AND NRORG = :NRORG";

        // Prepara o statement da query para execução.
        $statement = $this->connection->prepare($sql);

        // Executa o statement com os paràmetros passados.
        $statement->execute($params);
    }
    
        /*
     * Função para excluir os dados gerados na procedure de ADRC.
     */
    public function deleteAdrcData($params) {
        // Query a ser executada.
        $sql = "DELETE FROM ARQMAGNETICO WHERE NRSEQARQMAG = :NRSEQARQMAG AND NRORG = :NRORG";

        // Prepara o statement da query para execução.
        $statement = $this->connection->prepare($sql);

        // Executa o statement com os paràmetros passados.
        $statement->execute($params);
    }

    /*
     * Função para retornar a sigla do estado relacionado a uma inscrição estadual.
     */
    public function getEstadoInscricaoEstadual($params) {
        // Query a ser executada.
        $sql = "SELECT SGESTADO FROM INSCRESTAD WHERE CDEMPRESA = :CDEMPRESA AND CDINSCESTA = :CDINSCESTA AND NRORG = :NRORG";

        // Prepara o statement da query para execução.
        $statement = $this->connection->prepare($sql);

        // Executa o statement com os paràmetros passados.
        $statement->execute($params);

        // Executa um fetch no primeiro dado, retornando-o.
        return $statement->fetch(\PDO::FETCH_ASSOC);
        
    }

    /*
     * Função para retornar os dados gerados na procedure de ValidaPR.
     */
    public function getValidaPrData($params) {
        
        // Query a ser executada.
        $sql = "SELECT NRSEQARQMAG, NRORDREGARQ, DSREGARQMAG as DSREGARQMAG 
                FROM ARQMAGNETICO 
                WHERE NRORG = :NRORG 
                    AND NRSEQARQMAG = :NRSEQARQMAG 
                ORDER BY NRORDREGARQ, SUBSTR(DSREGARQMAG,1,17)";

        // Prepara o statement da query para execução.
        $statement = $this->connection->prepare($sql);

        // Executa o statement com os paràmetros passados.
        $statement->execute($params);

        // Executa um fetch no primeiro dado, retornando-o.
        return $statement->fetchAll();
    }    
    
    public function findAgendamento() {
        // Query a ser executada.
        $sql = "SELECT 
                    A.NRORG,
                    A.NRAGENDAMENTO,
                    A.CDTELA,
                    A.CDEMPRESA,
                    E.NMEMPRESA,
                    A.CDINSCESTA,
                    A.DTAGENDAMENTO,
                    A.DTINICIAL,
                    A.DTFINAL,
                    A.CDCAMPO1 AS CDIMPOSTONFE,
                    A.CDCAMPO2 AS CDPAIS,
                    A.CDCAMPO3 AS SGESTADO,
                    DECODE(A.IDPERIAGEN, '0', A.DTINICIAL,
                                   '1', TO_CHAR(SYSDATE, 'DD/MM/YYYY'),
                                   '2', TO_CHAR(ADD_MONTHS(SYSDATE,(-1)), 'DD/MM/YYYY')) AS DTREFINI,
                    I.SGIMPOSTONFE,
                    A.IDPERIAGEN,
                    A.IDSTATUS
                    FROM AGENDOBRIGACESS A,
                    EMPRESA E,
                    IMPOSTONFE I
                    WHERE CDTELA  = 'FIS07600'
                    AND A.CDEMPRESA = E.CDEMPRESA
                    AND A.CDCAMPO1 = I.CDIMPOSTONFE";
                    

        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute();
        
        // Executa um fetch no primeiro dado, retornando-o.
        return $std->fetchAll();
    }
    
    public function insertAgendamento($row) {
        $sql = "INSERT INTO AGENDOBRIGACESS
            ( 
                NRORG,
                NRAGENDAMENTO,
                CDTELA,
            	CDEMPRESA,
                CDINSCESTA,
            	DTAGENDAMENTO,
            	DTINICIAL,
            	DTFINAL,
                IDPERIAGEN,
            	
            	CDCAMPO1,
                CDCAMPO2,
                CDCAMPO3,
                DTCAMPO1   ) 
             VALUES (
                :NRORG,
                :NRAGENDAMENTO,
                :CDTELA,
                :CDEMPRESA,
                :CDINSCESTA,
                :DTAGENDAMENTO,
                :DTINICIAL,
                :DTFINAL,
                :IDPERIAGEN,
                :CDCAMPO1,
                :CDCAMPO2,
                :CDCAMPO3,
                :DTCAMPO1 )";
                
        $params = array(
            "NRORG"         => $row["NRORG"],
            "NRAGENDAMENTO" => $row["NRAGENDAMENTO"],
            "CDTELA"        => $row["CDTELA"],
            "CDEMPRESA"     => $row["CDEMPRESA"],
            "CDINSCESTA"    => $row["CDINSCESTA"],
            "DTAGENDAMENTO" => $row["DTAGENDAMENTO"],
            
            //Campos da tabela que serão salvos e os campos da declaração
            "DTINICIAL" => $row["DTINICIAL"],
            "DTFINAL"   => $row["DTFINAL"],
            "IDPERIAGEN"=> $row["IDPERIAGEN"],
            "CDCAMPO1"  => $row["CDIMPOSTONFE"],
            "CDCAMPO2"  => $row["CDPAIS"],
            "CDCAMPO3"  => $row["SGESTADO"],
            "DTCAMPO1"  => $row["DTREFINI"]
        );
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function updateAgendamento($row) {
        $sql = "UPDATE AGENDOBRIGACESS
                    SET CDEMPRESA = :CDEMPRESA,
                        CDINSCESTA = :CDINSCESTA,
                    	DTAGENDAMENTO = :DTAGENDAMENTO,
                    	DTINICIAL = :DTINICIAL,
                    	DTFINAL = :DTFINAL,
                    	IDPERIAGEN = :IDPERIAGEN,
                    	CDCAMPO1 = :CDCAMPO1,
                        CDCAMPO2 = :CDCAMPO2,
                        CDCAMPO3 = :CDCAMPO3,
                        DTCAMPO1 = :DTCAMPO1
                    WHERE NRAGENDAMENTO = :NRAGENDAMENTO
                    AND CDTELA = :CDTELA";
                    
        $params = array(
            "NRAGENDAMENTO" => $row["NRAGENDAMENTO"],
            "CDTELA"        => $row["CDTELA"],
            "CDEMPRESA"     => $row["CDEMPRESA"],
            "CDINSCESTA"    => $row["CDINSCESTA"],
            "DTAGENDAMENTO" => $row["DTAGENDAMENTO"],
            
            //Campos da tabela que serão salvos e os campos da declaração
            "DTINICIAL" => $row["DTINICIAL"],
            "DTFINAL"   => $row["DTFINAL"],
            "IDPERIAGEN"=> $row["IDPERIAGEN"],
            "CDCAMPO1"  => $row["CDIMPOSTONFE"],
            "CDCAMPO2"  => $row["CDPAIS"],
            "CDCAMPO3"  => $row["SGESTADO"],
            "DTCAMPO1"  => $row["DTREFINI"]
        );
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function updateAgendamentoIdStatus($row, $idstatus) {
        $sql = "UPDATE AGENDOBRIGACESS
                    SET IDSTATUS = :IDSTATUS
                    WHERE NRAGENDAMENTO = :NRAGENDAMENTO
                    AND CDTELA = :CDTELA";
                    
        $params = array(
            "NRAGENDAMENTO" => $row["NRAGENDAMENTO"],
            "CDTELA"        => $row["CDTELA"],
            "IDSTATUS"      => $idstatus
        );
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function getInscEsta($row) {
        // Query a ser executada.
        $sql = "SELECT CDINSCESTA FROM INSCRESTAD WHERE CDEMPRESA = :CDEMPRESA";

        $params = array(
            'CDEMPRESA' => $row['CDEMPRESA']
        );
        
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
        // Executa um fetch no primeiro dado, retornando-o.
        return $std->fetchAll();
    }
    
    public function getAgendamentoInsert($row) {
        // Query a ser executada.
        $sql = "SELECT * FROM AGENDOBRIGACESS 
                    WHERE NRAGENDAMENTO = :NRAGENDAMENTO";

        $params = array(
            "NRAGENDAMENTO"=>$row["NRAGENDAMENTO"]
        );
        
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
        // Executa um fetch no primeiro dado, retornando-o.
        return $std->fetchAll();
    }
    
    public function getConfiguraSMTP($row)  {
        // Query a ser executada.
        $sql = "SELECT * FROM CONFIGURASMTP
                    WHERE NRORG = :NRORG";
        
        $params = array(
            "NRORG"=> $row["NRORG"]
        );
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
        // Executa um fetch no primeiro dado, retornando-o.
        //var_dump($std->fetchAll());
        return $std->fetchAll();
    }
    
    public function getContatos($row)  {
        // Query a ser executada.
        $sql = "SELECT * FROM CONTATOAPURAC
                    WHERE NRORG = :NRORG
                    AND CDEMPRESA = :CDEMPRESA
                    AND IDEXPORTAUTO = 'S'";
        
        $params = array(
            "NRORG"     => $row["NRORG"],
            "CDEMPRESA" => $row["CDEMPRESA"]
        );
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
        // Executa um fetch no primeiro dado, retornando-o.
        //var_dump($std->fetchAll());
        return $std->fetchAll();
    }
    
    public function getAgendamentoArquivo($row) {
        $sql = "SELECT * FROM ARQUIOBRIGACESS
                WHERE NRAGENDAMENTO = :NRAGENDAMENTO";
        
        $params = array(
            "NRAGENDAMENTO" => $row["NRAGENDAMENTO"]
        );
        
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
        // Executa um fetch no primeiro dado, retornando-o.
        return $std->fetchAll();
    }
    
    public function deleteAgendamentoArquivo($row) {
        $sql = "DELETE FROM ARQUIOBRIGACESS
                WHERE NRAGENDAMENTO = :NRAGENDAMENTO";
        
        $params = array(
            "NRAGENDAMENTO" => $row["NRAGENDAMENTO"]
        );
        
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
    }
  
    public function deleteAgendamento($row) {
        // Query a ser executada.
        $sql = "DELETE FROM AGENDOBRIGACESS 
                    WHERE NRAGENDAMENTO = :NRAGENDAMENTO";

        $params = array(
            "NRAGENDAMENTO"=>$row["NRAGENDAMENTO"]
        );
        
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
    }
    
    public function findAgendamentoExec($row) {
        // Query a ser executada.
        $sql = "SELECT 
                    TO_CHAR(SYSDATE, 'DD/MM/YYYY HH24:MI') AS DTATUAL,
                    TO_CHAR(ADD_MONTHS(SYSDATE,(-1)), 'DD/MM/YYYY HH24:MI') AS LAST_MONTH,
                    A.NRAGENDAMENTO,
                    A.CDTELA,
                    A.CDEMPRESA,
                    A.CDINSCESTA,
                    A.DTAGENDAMENTO,
                    A.DTINICIAL,
                    A.DTFINAL,
                    A.CDCAMPO1 AS CDIMPOSTONFE,
                    A.CDCAMPO2 AS CDPAIS,
                    A.CDCAMPO3 AS SGESTADO,
                    A.DTCAMPO1 AS DTREFINI,
                    A.IDPERIAGEN,
                    A.IDSTATUS
                    FROM AGENDOBRIGACESS A
                    WHERE NRAGENDAMENTO = :NRAGENDAMENTO";
        
        $params = array(
            "NRAGENDAMENTO"=> $row["NRAGENDAMENTO"]
        );
        
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
        // Executa um fetch no primeiro dado, retornando-o.
        //var_dump($std->fetchAll());
        return $std->fetchAll();
    }
    
    public function findParamDeclAcess($row) {
        // Query a ser executada.
        $sql = "SELECT
                 CDCAMPO1    AS CDCONVENIO,
                 CDCAMPO2    AS CDFINALIDADE,
                 CDCAMPO3    AS CDREGISTRO
             FROM
                 PARAMDECLACES
             WHERE
                 CDTELA =:CDTELA
                 AND CDEMPRESA =:CDEMPRESA";
        
        $params = array(
            "CDTELA"    => $row["CDTELA"],
            "CDEMPRESA" => $row["CDEMPRESA"]
        );
        
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
        // Executa um fetch no primeiro dado, retornando-o.
        //var_dump($std->fetchAll());
        return $std->fetch();
    }
    
    public function getNmEmpresa($row) {
        // Query a ser executada.
        $sql = "SELECT NMEMPRESA FROM EMPRESA
                    WHERE CDEMPRESA = :CDEMPRESA
                    AND NRORG = :NRORG";
        
        $params = array(
            "CDEMPRESA" => $row["CDEMPRESA"],
            "NRORG"     => $row["NRORG"]
        );
        
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
        // Executa um fetch no primeiro dado, retornando-o.
        //var_dump($std->fetchAll());
        return $std->fetch();
    }
    
    public function verAgendamentoArquivo($row) {
        $sql = "SELECT * FROM ARQUIOBRIGACESS
                WHERE NRAGENDAMENTO = :NRAGENDAMENTO
                AND NMARQUIVO = :NMARQUIVO";
        
        $params = array(
            "NRAGENDAMENTO" => $row["NRAGENDAMENTO"],
            "NMARQUIVO"     => $row["NMARQUIVO"]
        );
        
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
        // Executa um fetch no primeiro dado, retornando-o.
        return $std->fetchAll();
    }
    
    public function insertAgendamentoArquivo($row) {
        $sql = "INSERT INTO ARQUIOBRIGACESS
            ( 
                NRORG,
                NRARQUIVO,
                NRAGENDAMENTO,
                CDTELA,
                CDEMPRESA,
                CDINSCESTA,
                DTAGENDAMENTO,
                DTEXECAGEND,
                NMARQUIVO,
                NMPATHARQ
            )
             VALUES (
                :NRORG,
                :NRARQUIVO,
                :NRAGENDAMENTO,
                :CDTELA,
                :CDEMPRESA,
                :CDINSCESTA,
                :DTAGENDAMENTO,
                :DTEXECAGEND,
                :NMARQUIVO,
                :NMPATHARQ  )";
        
        $params = array(
            "NRORG"         => $row["NRORG"],
            "NRARQUIVO"     => $row["NRARQUIVO"],
            "NRAGENDAMENTO" => $row["NRAGENDAMENTO"],
            "CDTELA"        => $row["CDTELA"],
            "CDEMPRESA"     => $row["CDEMPRESA"],
            "CDINSCESTA"    => $row["CDINSCESTA"],
            "DTAGENDAMENTO" => $row["DTAGENDAMENTO"],
            "DTEXECAGEND"   => $row["DTEXECAGEND"],
            "NMARQUIVO"     => $row["NMARQUIVO"],
            "NMPATHARQ"     => $row["NMPATHARQ"]
        );
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    
    
    
    // ESSA PARTE É DESTINADA PARA AS FUNÇÕES DA FIS08300_GIAMTO
    
    
        /**
     * Executa a procedure para a exportação de ValidaTo [GIAM_TO]
     */
    public function callGiamToProcedure($params) {
        $procedure = new StoredProcedure($this->connection, 'GIAM_TO');
        
        $procedure->addParam(new Param('P_CDEMPRESA', Param::PARAM_INPUT, $params["CDEMPRESA"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDINSCESTA', Param::PARAM_INPUT, $params["CDINSCESTA"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_LIVRO', Param::PARAM_INPUT, $params["LIVRO"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTINICIO', Param::PARAM_INPUT, $params["DTINICIO"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTFIM', Param::PARAM_INPUT, $params["DTFIM"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRSEQARQMAG', Param::PARAM_INPUT, $params["NRSEQARQMAG"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDRETIFIC', Param::PARAM_INPUT, $params["IDRETIFIC"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDTPESTAB', Param::PARAM_INPUT, $params["IDTPESTAB"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDPORTTARE', Param::PARAM_INPUT, $params["IDPORTTARE"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDTPESCRIT', Param::PARAM_INPUT, $params["IDTPESCRIT"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_VRINICAIXA', Param::PARAM_INPUT, $params["VRINICAIXA"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_VRFIMCAIXA', Param::PARAM_INPUT, $params["VRFIMCAIXA"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDUSAECF', Param::PARAM_INPUT, $params["IDUSAECF"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDREPRESENT', Param::PARAM_INPUT, $params["CDREPRESENT"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRTARE', Param::PARAM_INPUT, $params["NRTARE"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_VERSAO', Param::PARAM_INPUT, $params["VERSAO"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTVENCTARE', Param::PARAM_INPUT, $params["DTVENCTARE"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDMUDDOMICI', Param::PARAM_INPUT, $params["IDMUDDOMICI"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDMUNIANT', Param::PARAM_INPUT, $params["CDMUNIANT"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTINIMUNIANT', Param::PARAM_INPUT, $params["DTINIMUNIANT"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTFINMUNIANT', Param::PARAM_INPUT, $params["DTFINMUNIANT"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTINIMUNIATU', Param::PARAM_INPUT, $params["DTINIMUNIATU"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTFINMUNIATU', Param::PARAM_INPUT, $params["DTFINMUNIATU"], Param::PARAM_TYPE_STR));
        $procedure->execute();
    }
    
   /*
     * Função para excluir os dados gerados na procedure de ValidaTO.
     */
    public function deleteGiamToData($params) {
        // Query a ser executada.
        $sql = "DELETE FROM ARQMAGNETICO WHERE NRSEQARQMAG = :NRSEQARQMAG AND NRORG = :NRORG";

        // Prepara o statement da query para execução.
        $statement = $this->connection->prepare($sql);

        // Executa o statement com os paràmetros passados.
        $statement->execute($params);
    }
    
     public function getGiamToData($params) {
        
        // Query a ser executada.
        $sql = "SELECT NRSEQARQMAG, NRORDREGARQ, DSREGARQMAG as DSREGARQMAG 
                FROM ARQMAGNETICO 
                WHERE NRORG = :NRORG 
                    AND NRSEQARQMAG = :NRSEQARQMAG 
                ORDER BY NRORDREGARQ, SUBSTR(DSREGARQMAG,1,17) ";

        // Prepara o statement da query para execução.
        $statement = $this->connection->prepare($sql);

        // Executa o statement com os paràmetros passados.
        $statement->execute($params);

        // Executa um fetch no primeiro dado, retornando-o.
        return $statement->fetchAll();
    }    
    
    
}